@@ -22,3 +22,12 @@ check_css = function(css) {
     " Use `pagedown:::list_css()` to view all built-in CSS filenames.", call. = FALSE
   )
 }
+
+merge_list = function(x, y) {
+  x[names(y)] = y
+  x
+}
+
+# don't prefer the port 4321 (otherwise we may see the meaningless error message
+# "createTcpServer: address already in use" too often)
+random_port = function() servr::random_port(NULL)
